# -*- coding: utf-8 -*-
"""
Created on Fri Nov  8 13:17:29 2013

@author: seppke
"""

import vigra as vi
import numpy as np

def regionAtBorder(img, region_bbox):
    ul, lr = region_bbox[0], region_bbox[1]
    
    return (ul[0]==0 or ul[1]==0) or (lr[0] == img.width-1 or lr[1] == img.height-1)

def regionNotCircleLike(region_radii, epsilon=2):
    return region_radii[0]/region_radii[1] > epsilon

img = vi.readImage('sichelzellen.jpg')
vi.imshow(img)

vi_img = vi.Image(img[...,0])
vi.imshow(vi_img)

vi_img_t = vi_img < 222
vi.imshow(vi_img_t)

vi_img_to = vi.filters.discOpening(vi_img_t.astype(np.uint8), 1)
vi.imshow(vi_img_to)


vi_label_img = vi.analysis.labelImageWithBackground(vi_img_to)

vi.imshow(vi_label_img)
vi.analysis.supportedRegionFeatures(vi_img, vi_label_img)

features = vi.analysis.extractRegionFeatures(vi_img, vi_label_img)
region_count = features.maxRegionLabel()+1

bboxes  = zip(features['Coord<Minimum >'],features['Coord<Maximum >'])

final_features=np.zeros(region_count)

vi_img_res = vi_img_to.copy()
    
for i in range(region_count):
    if regionAtBorder(img, bboxes[i]):
       final_features[i] = 0
    elif features['Count'][i] < 50:
        final_features[i] = 0
    elif regionNotCircleLike(features['RegionRadii'][i]):
        final_features[i] = 2
    else:
        final_features[i] = 1
    vi_img_res[np.where(vi_label_img ==i)] = final_features[i]
vi.imshow(vi_img_res)
